<p align="center">
  <a href="https://v2.nonebot.dev/"><img src="https://v2.nonebot.dev/logo.png" width="200" height="200" alt="nonebot"></a>
</p>
<div align="center">

# nonebot-plugin-warthunder-player-check
_✨ Warthunder玩家战绩查询插件 ✨_

<a href="https://github.com/Utmost-Happiness-Planet/uhpstatus/blob/main/LICENSE">
    <img src="https://img.shields.io/badge/license-GPL%20v3.0-orange" alt="license">
  </a>
  <a href="https://github.com/nonebot/nonebot2">
    <img src="https://img.shields.io/badge/nonebot-v2-red" alt="nonebot">
  </a>
  <a href="">
    <img src="https://img.shields.io/badge/release-v3.0-blueviolet" alt="release">
</a>
</div>

## 简介
俄罗斯原神话题中，还在因和别人对线时想查对方履历亦或者当kd警察但开游戏太麻烦或者暂时开不了只能让对面跳而烦恼吗？那赶快使用此插件，用实际数据证明对方是不是傻逼雷批吧！

## 使用方式
 - 在nb-cli使用 `nb install nonebot-plugin-warthunder-player-check`~~（使用pip的默认你会在pyproject.toml添加）~~
 - 发送 Command `战雷查水表` 或 `warthunder` 或直接 `战雷查水表 [玩家id]`~~（支持模糊搜索，但是有空格请用%替换）~~

## 配置项
  需要安装Chrome浏览器以及对应版本的driver<a href="https://github.com/Utmost-Happiness-Planet/uhpstatus/blob/main/LICENSE">